
rawset(_G, "HugeQuest", "V1") -- Heyo!

local hq_hugespeed = CV_RegisterVar({
    name = "hq_hugespeed",
    defaultvalue = "0.1",
    flags = CV_NETVAR|CV_FLOAT,
    PossibleValue = {MIN = 0, MAX = INT32_MAX}
})
rawset(_G, "growplus", {speedmod = hq_hugespeed.value})

local dispinfo = {
	{"Grow+", hq_huge},
	{"Grow+ Free Orbi", hq_orbigift},
	{"Grow+ Double Damage", hq_yeet},
	{"Grow+ Offroad Immunity", hq_offroad},
	{"Midair MT Storage", hq_mtstore},
	{"Stackable Inv. Duration", hq_sparkle}
}

COM_AddCommand("hq_info", function(p)

	CONS_Printf(p, "\x89".."Running HugeQuest "..HugeQuest)
	CONS_Printf(p, "Feature List:")
	for i = 1, #dispinfo
		local info = dispinfo[i]
		local clr = info[2].value and "\x8B".."ON" or "\x8A".."OFF"

		CONS_Printf(p, "\x89"..info[2].name.."\x80"..": ("..info[1]..") - "..clr)
	end
	CONS_Printf(p, "Type \'hq_help <command name>\' for more details about the above commands")
end)

local help = {
	{"Enables item usage during Grow and alters item properties while active. Using Grow while Grow+ is active extends the duration.", hq_huge},
	{"Grants a temporary Orbinaut on Grow+ activation. It will disappear if not used when Grow+ runs out.", hq_orbigift},
	{"Extends spinout inflicted when hitting players with items used by a Grow+ player.", hq_yeet},
	{"Grants offroad immunity (indicated by a green flash) during Grow+, at the cost of reduced duration (10 seconds) and total speed bonus (65%). If OFF, duration and bonus are equal to Vanilla Grow (12 seconds and 80% total speed bonus).", hq_offroad},
	{"Preserves Mini-Turbo in the air and during sneaker effects. MT storage during sneaker effects is indicated by green fastlines.", hq_mtstore},
	{"Extends Invincibility duration when used while Invincibility is active.", hq_sparkle},
	{"Determines speedboost during Grow+.", hq_hugespeed}
}

COM_AddCommand("hq_help", function(p, arg)

	if not arg return end
	arg = arg:lower()

	for i = 1, #help
		if arg == help[i][2].name
			CONS_Printf(p, "\x89"..help[i][2].name.."\x80"..":\n"..help[i][1])
			return
		end
	end
	CONS_Printf(p, "No command named \'"..arg.."\' in HugeQuest. Please use \'hq_info\' to view a list of all the commands.")
end)

local init = false
addHook("NetVars", function(net)
	init = net(init)
end)
addHook("ThinkFrame", function()
	if not init then
		if HOSTMOD and leveltime > TICRATE then
			HM_Scoreboard_AddMod({disp = "Midair MT Storage", var = "hq_mtstore"})
			HM_Scoreboard_AddMod({disp = "Grow Timer Stack", var = "hq_huge"})
			HM_Scoreboard_AddMod({disp = "Grow Orbi Split", var = "hq_huge"})
			HM_Scoreboard_AddMod({disp = "Grow Banana Split", var = "hq_huge"})
			HM_Scoreboard_AddMod({disp = "Inv Timer Stack", var = "hq_sparkle"})
			HM_Scoreboard_AddMod({disp = "Grow Orbi Gift", var = "hq_orbigift"})
			HM_Scoreboard_AddMod({disp = "Variable Grow+ Speed Boost", var = "hq_hugespeed"})
		end
		init = true
	end
	for p in players.iterate do
		if not (p.mo and p.mo.valid) or p.spectator continue end
		if not p.hq_infohelp -- Thanks, Lat
			COM_BufInsertText(p, "hq_info")
			chatprintf(p, "\x88".."*Server is running HugeQuest "..HugeQuest.."\nType \'".."\x89".."hq_info".."\x88".."\' in the console for details on the settings used.")
			p.hq_infohelp = true
		end
	end	
	
	if hq_offroad.value then
		growplus.speedmod = hq_hugespeed.value
	else
		growplus.speedmod = hq_hugespeed.value*2 //No offroad immunity? Double the Speedboost
	end
end)